==> freej_0.8.1.orig.tar.gz: freej-0.8.1/lib/avcodec/config.h <==
// FreeJ avcodec configuration
#define FFMPEG_CONFIGURATION " --prefix=/usr --enable-shared --enable-libogg --enable-vorbis --enable-mp3lame --enable-xvid --enable-theora --enable-a52 --enable-gpl --enable-faad --enable-faac --cpu=pentium-mmx "
#define TUNECPU generic
#define HAVE_BUILTIN_VECTOR 1
#define HAVE_LOCALTIME_R 1
#define HAVE_LRINTF 1
#define HAVE_VHOOK 1
#define CONFIG_ENCODERS 1
#define CONFIG_DECODERS 1
#define CONFIG_AC3 1
#define CONFIG_MPEGAUDIO_HP 1
// #define CONFIG_VIDEO4LINUX 1
// #define CONFIG_DV1394 1
#define CONFIG_HAVE_DLOPEN 1
#define CONFIG_HAVE_DLFCN 1
// #define CONFIG_AUDIO_OSS 1
#define CONFIG_NETWORK 1
// #define CONFIG_IPV6 1
#define CONFIG_ZLIB 1
// #define CONFIG_MP3LAME 1
#define CONFIG_LIBOGG 1
#define CONFIG_LIBVORBIS 1
#define CONFIG_LIBTHEORA 1
// #define CONFIG_FAAD 1
// #define CONFIG_FAAC 1
// #define CONFIG_XVID 1
#define HAVE_MALLOC_H 1
#define HAVE_MEMALIGN 1
#define SIMPLE_IDCT 1
// #define CONFIG_FFSERVER 1
#define CONFIG_GPL 1
#define restrict __restrict__
// #define CONFIG_AC3_ENCODER 1
// #define CONFIG_MP2_ENCODER 1
// #define CONFIG_MP3LAME_ENCODER 1
#define CONFIG_OGGVORBIS_ENCODER 1
#define CONFIG_OGGVORBIS_DECODER 1
#define CONFIG_OGGTHEORA_ENCODER 1
#define CONFIG_OGGTHEORA_DECODER 1
// #define CONFIG_FAAC_ENCODER 1
// #define CONFIG_XVID_ENCODER 1
#define CONFIG_MPEG1VIDEO_ENCODER 1
// #define CONFIG_H264_ENCODER 1
// #define CONFIG_MPEG2VIDEO_ENCODER 1
// #define CONFIG_H261_ENCODER 1
// #define CONFIG_H263_ENCODER 1
// #define CONFIG_H263P_ENCODER 1
// #define CONFIG_FLV_ENCODER 1
// #define CONFIG_RV10_ENCODER 1
// #define CONFIG_RV20_ENCODER 1
#define CONFIG_MPEG4_ENCODER 1
#define CONFIG_MSMPEG4V1_ENCODER 1
#define CONFIG_MSMPEG4V2_ENCODER 1
#define CONFIG_MSMPEG4V3_ENCODER 1
#define CONFIG_WMV1_ENCODER 1
#define CONFIG_WMV2_ENCODER 1
#define CONFIG_SVQ1_ENCODER 1
#define CONFIG_MJPEG_ENCODER 1
#define CONFIG_LJPEG_ENCODER 1
#define CONFIG_PNG_ENCODER 1
#define CONFIG_PPM_ENCODER 1
#define CONFIG_PGM_ENCODER 1
#define CONFIG_PGMYUV_ENCODER 1
#define CONFIG_PBM_ENCODER 1
#define CONFIG_PAM_ENCODER 1
#define CONFIG_HUFFYUV_ENCODER 1
#define CONFIG_FFVHUFF_ENCODER 1
#define CONFIG_ASV1_ENCODER 1
#define CONFIG_ASV2_ENCODER 1
#define CONFIG_FFV1_ENCODER 1
#define CONFIG_SNOW_ENCODER 1
#define CONFIG_ZLIB_ENCODER 1
#define CONFIG_DVVIDEO_ENCODER 1
#define CONFIG_SONIC_ENCODER 1
#define CONFIG_SONIC_LS_ENCODER 1
// #define CONFIG_X264_ENCODER 1
#define CONFIG_LIBGSM_ENCODER 1
#define CONFIG_RAWVIDEO_ENCODER 1

//////////////////////////////////
// decoders

#define CONFIG_RAWVIDEO_DECODER 1
#define CONFIG_H263_DECODER 1
#define CONFIG_H261_DECODER 1
#define CONFIG_MPEG4_DECODER 1
#define CONFIG_MSMPEG4V1_DECODER 1
#define CONFIG_MSMPEG4V2_DECODER 1
#define CONFIG_MSMPEG4V3_DECODER 1
#define CONFIG_WMV1_DECODER 1
#define CONFIG_WMV2_DECODER 1
#define CONFIG_VC9_DECODER 1
#define CONFIG_WMV3_DECODER 1
#define CONFIG_H263I_DECODER 1
#define CONFIG_FLV_DECODER 1
#define CONFIG_RV10_DECODER 1
#define CONFIG_RV20_DECODER 1
#define CONFIG_SVQ1_DECODER 1
#define CONFIG_SVQ3_DECODER 1
#define CONFIG_WMAV1_DECODER 1
#define CONFIG_WMAV2_DECODER 1
#define CONFIG_INDEO2_DECODER 1
#define CONFIG_INDEO3_DECODER 1
#define CONFIG_TSCC_DECODER 1
#define CONFIG_ULTI_DECODER 1
#define CONFIG_QDRAW_DECODER 1
#define CONFIG_XL_DECODER 1
#define CONFIG_QPEG_DECODER 1
#define CONFIG_LOCO_DECODER 1
#define CONFIG_WNV1_DECODER 1
#define CONFIG_AASC_DECODER 1
#define CONFIG_FRAPS_DECODER 1
#define CONFIG_AAC_DECODER 1
#define CONFIG_MPEG4AAC_DECODER 1
#define CONFIG_MPEG1VIDEO_DECODER 1
#define CONFIG_MPEG2VIDEO_DECODER 1
#define CONFIG_MPEGVIDEO_DECODER 1
#define CONFIG_MPEG_XVMC_DECODER 1
#define CONFIG_DVVIDEO_DECODER 1
#define CONFIG_MJPEG_DECODER 1
#define CONFIG_MJPEGB_DECODER 1
#define CONFIG_SP5X_DECODER 1
#define CONFIG_PNG_DECODER 1
#define CONFIG_MP2_DECODER 1
#define CONFIG_MP3_DECODER 1
#define CONFIG_MP3ADU_DECODER 1
#define CONFIG_MP3ON4_DECODER 1
#define CONFIG_MACE3_DECODER 1
#define CONFIG_MACE6_DECODER 1
#define CONFIG_HUFFYUV_DECODER 1
#define CONFIG_FFVHUFF_DECODER 1
#define CONFIG_FFV1_DECODER 1
#define CONFIG_SNOW_DECODER 1
#define CONFIG_CYUV_DECODER 1
#define CONFIG_H264_DECODER 1
#define CONFIG_VP3_DECODER 1
#define CONFIG_THEORA_DECODER 1
#define CONFIG_ASV1_DECODER 1
#define CONFIG_ASV2_DECODER 1
#define CONFIG_VCR1_DECODER 1
#define CONFIG_CLJR_DECODER 1
#define CONFIG_FOURXM_DECODER 1
#define CONFIG_MDEC_DECODER 1
#define CONFIG_ROQ_DECODER 1
#define CONFIG_INTERPLAY_VIDEO_DECODER 1
#define CONFIG_XAN_WC3_DECODER 1
#define CONFIG_RPZA_DECODER 1
#define CONFIG_CINEPAK_DECODER 1
#define CONFIG_MSRLE_DECODER 1
#define CONFIG_MSVIDEO1_DECODER 1
#define CONFIG_VQA_DECODER 1
#define CONFIG_IDCIN_DECODER 1
#define CONFIG_EIGHTBPS_DECODER 1
#define CONFIG_SMC_DECODER 1
#define CONFIG_FLIC_DECODER 1
#define CONFIG_TRUEMOTION1_DECODER 1
#define CONFIG_VMDVIDEO_DECODER 1
#define CONFIG_VMDAUDIO_DECODER 1
#define CONFIG_MSZH_DECODER 1
#define CONFIG_ZLIB_DECODER 1
#define CONFIG_SONIC_DECODER 1
#define CONFIG_AC3_DECODER 1
#define CONFIG_DTS_DECODER 1
#define CONFIG_RA_144_DECODER 1
#define CONFIG_RA_288_DECODER 1
#define CONFIG_ROQ_DPCM_DECODER 1
#define CONFIG_INTERPLAY_DPCM_DECODER 1
#define CONFIG_XAN_DPCM_DECODER 1
#define CONFIG_SOL_DPCM_DECODER 1
#define CONFIG_QTRLE_DECODER 1
// #define CONFIG_FLAC_DECODER 1
#define CONFIG_SHORTEN_DECODER 1
#define CONFIG_ALAC_DECODER 1
#define CONFIG_WS_SND1_DECODER 1
#define CONFIG_VORBIS_DECODER 1
// #define CONFIG_LIBGSM_DECODER 1
#define CONFIG_AMR_NB_DECODER 1
#define CONFIG_AMR_NB_ENCODER 1
#define CONFIG_AMR_WB_DECODER 1
#define CONFIG_AMR_WB_ENCODER 1
#define CONFIG_DVDSUB_DECODER 1
#define CONFIG_DVBSUB_ENCODER 1
#define CONFIG_DVBSUB_DECODER 1

// architecture

#define HAVE_MMX 1
#define __CPU__ 586

==> freej-0.9.tar.gz: freej-0.9/lib/avcodec/config.h <==

#include "../../config.h"

// FreeJ avcodec configuration
#define FFMPEG_CONFIGURATION " --prefix=/usr --enable-shared --enable-libogg --enable-vorbis --enable-mp3lame --enable-xvid --enable-theora --enable-a52 --enable-gpl --enable-faad --enable-faac --cpu=pentium-mmx "
#define TUNECPU generic
#define HAVE_BUILTIN_VECTOR 1
#define HAVE_LOCALTIME_R 1
#define HAVE_LRINTF 1
#define HAVE_VHOOK 1
#define CONFIG_ENCODERS 1
#define CONFIG_DECODERS 1
#define CONFIG_AC3 1
#define CONFIG_MPEGAUDIO_HP 1
// #define CONFIG_VIDEO4LINUX 1
// #define CONFIG_DV1394 1
#define CONFIG_HAVE_DLOPEN 1
#define CONFIG_HAVE_DLFCN 1
// #define CONFIG_AUDIO_OSS 1
#define CONFIG_NETWORK 1
// #define CONFIG_IPV6 1
#define CONFIG_ZLIB 1
// #define CONFIG_MP3LAME 1
// these are now defined by configure
// #define CONFIG_LIBOGG 1
// #define CONFIG_LIBVORBIS 1
// #define CONFIG_LIBTHEORA 1
// #define CONFIG_FAAD 1
// #define CONFIG_FAAC 1
// #define CONFIG_XVID 1
#define HAVE_MALLOC_H 1
#define HAVE_MEMALIGN 1
#define SIMPLE_IDCT 1
// #define CONFIG_FFSERVER 1
#define CONFIG_GPL 1
#define restrict __restrict__
// #define CONFIG_AC3_ENCODER 1
// #define CONFIG_MP2_ENCODER 1
// #define CONFIG_MP3LAME_ENCODER 1
// #define CONFIG_OGGVORBIS_ENCODER 1
// #define CONFIG_OGGVORBIS_DECODER 1
// #define CONFIG_OGGTHEORA_ENCODER 1
// #define CONFIG_OGGTHEORA_DECODER 1
// #define CONFIG_FAAC_ENCODER 1
// #define CONFIG_XVID_ENCODER 1
#define CONFIG_MPEG1VIDEO_ENCODER 1
// #define CONFIG_H264_ENCODER 1
// #define CONFIG_MPEG2VIDEO_ENCODER 1
// #define CONFIG_H261_ENCODER 1
// #define CONFIG_H263_ENCODER 1
// #define CONFIG_H263P_ENCODER 1
// #define CONFIG_FLV_ENCODER 1
// #define CONFIG_RV10_ENCODER 1
// #define CONFIG_RV20_ENCODER 1
#define CONFIG_MPEG4_ENCODER 1
#define CONFIG_MSMPEG4V1_ENCODER 1
#define CONFIG_MSMPEG4V2_ENCODER 1
#define CONFIG_MSMPEG4V3_ENCODER 1
#define CONFIG_WMV1_ENCODER 1
#define CONFIG_WMV2_ENCODER 1
#define CONFIG_SVQ1_ENCODER 1
#define CONFIG_MJPEG_ENCODER 1
#define CONFIG_LJPEG_ENCODER 1
#define CONFIG_PNG_ENCODER 1
#define CONFIG_PPM_ENCODER 1
#define CONFIG_PGM_ENCODER 1
#define CONFIG_PGMYUV_ENCODER 1
#define CONFIG_PBM_ENCODER 1
#define CONFIG_PAM_ENCODER 1
#define CONFIG_HUFFYUV_ENCODER 1
#define CONFIG_FFVHUFF_ENCODER 1
#define CONFIG_ASV1_ENCODER 1
#define CONFIG_ASV2_ENCODER 1
#define CONFIG_FFV1_ENCODER 1
#define CONFIG_SNOW_ENCODER 1
#define CONFIG_ZLIB_ENCODER 1
#define CONFIG_DVVIDEO_ENCODER 1
#define CONFIG_SONIC_ENCODER 1
#define CONFIG_SONIC_LS_ENCODER 1
// #define CONFIG_X264_ENCODER 1
#define CONFIG_LIBGSM_ENCODER 1
#define CONFIG_RAWVIDEO_ENCODER 1

//////////////////////////////////
// decoders

#define CONFIG_RAWVIDEO_DECODER 1
#define CONFIG_H263_DECODER 1
#define CONFIG_H261_DECODER 1
#define CONFIG_MPEG4_DECODER 1
#define CONFIG_MSMPEG4V1_DECODER 1
#define CONFIG_MSMPEG4V2_DECODER 1
#define CONFIG_MSMPEG4V3_DECODER 1
#define CONFIG_WMV1_DECODER 1
#define CONFIG_WMV2_DECODER 1
#define CONFIG_VC9_DECODER 1
#define CONFIG_WMV3_DECODER 1
#define CONFIG_H263I_DECODER 1
#define CONFIG_FLV_DECODER 1
#define CONFIG_RV10_DECODER 1
#define CONFIG_RV20_DECODER 1
#define CONFIG_SVQ1_DECODER 1
#define CONFIG_SVQ3_DECODER 1
#define CONFIG_WMAV1_DECODER 1
#define CONFIG_WMAV2_DECODER 1
#define CONFIG_INDEO2_DECODER 1
#define CONFIG_INDEO3_DECODER 1
#define CONFIG_TSCC_DECODER 1
#define CONFIG_ULTI_DECODER 1
#define CONFIG_QDRAW_DECODER 1
#define CONFIG_XL_DECODER 1
#define CONFIG_QPEG_DECODER 1
#define CONFIG_LOCO_DECODER 1
#define CONFIG_WNV1_DECODER 1
#define CONFIG_AASC_DECODER 1
#define CONFIG_FRAPS_DECODER 1
#define CONFIG_AAC_DECODER 1
#define CONFIG_MPEG4AAC_DECODER 1
#define CONFIG_MPEG1VIDEO_DECODER 1
#define CONFIG_MPEG2VIDEO_DECODER 1
#define CONFIG_MPEGVIDEO_DECODER 1
#define CONFIG_MPEG_XVMC_DECODER 1
#define CONFIG_DVVIDEO_DECODER 1
#define CONFIG_MJPEG_DECODER 1
#define CONFIG_MJPEGB_DECODER 1
#define CONFIG_SP5X_DECODER 1
#define CONFIG_PNG_DECODER 1
#define CONFIG_MP2_DECODER 1
#define CONFIG_MP3_DECODER 1
#define CONFIG_MP3ADU_DECODER 1
#define CONFIG_MP3ON4_DECODER 1
#define CONFIG_MACE3_DECODER 1
#define CONFIG_MACE6_DECODER 1
#define CONFIG_HUFFYUV_DECODER 1
#define CONFIG_FFVHUFF_DECODER 1
#define CONFIG_FFV1_DECODER 1
#define CONFIG_SNOW_DECODER 1
#define CONFIG_CYUV_DECODER 1
#define CONFIG_H264_DECODER 1
#define CONFIG_VP3_DECODER 1
#define CONFIG_THEORA_DECODER 1
#define CONFIG_ASV1_DECODER 1
#define CONFIG_ASV2_DECODER 1
#define CONFIG_VCR1_DECODER 1
#define CONFIG_CLJR_DECODER 1
#define CONFIG_FOURXM_DECODER 1
#define CONFIG_MDEC_DECODER 1
#define CONFIG_ROQ_DECODER 1
#define CONFIG_INTERPLAY_VIDEO_DECODER 1
#define CONFIG_XAN_WC3_DECODER 1
#define CONFIG_RPZA_DECODER 1
#define CONFIG_CINEPAK_DECODER 1
#define CONFIG_MSRLE_DECODER 1
#define CONFIG_MSVIDEO1_DECODER 1
#define CONFIG_VQA_DECODER 1
#define CONFIG_IDCIN_DECODER 1
#define CONFIG_EIGHTBPS_DECODER 1
#define CONFIG_SMC_DECODER 1
#define CONFIG_FLIC_DECODER 1
#define CONFIG_TRUEMOTION1_DECODER 1
#define CONFIG_VMDVIDEO_DECODER 1
#define CONFIG_VMDAUDIO_DECODER 1
#define CONFIG_MSZH_DECODER 1
#define CONFIG_ZLIB_DECODER 1
#define CONFIG_SONIC_DECODER 1
#define CONFIG_AC3_DECODER 1
#define CONFIG_DTS_DECODER 1
#define CONFIG_RA_144_DECODER 1
#define CONFIG_RA_288_DECODER 1
#define CONFIG_ROQ_DPCM_DECODER 1
#define CONFIG_INTERPLAY_DPCM_DECODER 1
#define CONFIG_XAN_DPCM_DECODER 1
#define CONFIG_SOL_DPCM_DECODER 1
#define CONFIG_QTRLE_DECODER 1
// #define CONFIG_FLAC_DECODER 1
#define CONFIG_SHORTEN_DECODER 1
#define CONFIG_ALAC_DECODER 1
#define CONFIG_WS_SND1_DECODER 1
#define CONFIG_VORBIS_DECODER 1
// #define CONFIG_LIBGSM_DECODER 1
#define CONFIG_AMR_NB_DECODER 1
#define CONFIG_AMR_NB_ENCODER 1
#define CONFIG_AMR_WB_DECODER 1
#define CONFIG_AMR_WB_ENCODER 1
#define CONFIG_DVDSUB_DECODER 1
#define CONFIG_DVBSUB_ENCODER 1
#define CONFIG_DVBSUB_DECODER 1
